==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/mskconnect_connector/MskconnectConnectorKafkaCluster.java <==
package com.hashicorp.cdktf.providers.aws.mskconnect_connector;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.816Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.mskconnectConnector.MskconnectConnectorKafkaCluster")
@software.amazon.jsii.Jsii.Proxy(MskconnectConnectorKafkaCluster.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MskconnectConnectorKafkaCluster extends software.amazon.jsii.JsiiSerializable {

    /**
     * apache_kafka_cluster block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/mskconnect_connector#apache_kafka_cluster MskconnectConnector#apache_kafka_cluster}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster getApacheKafkaCluster();

    /**
     * @return a {@link Builder} of {@link MskconnectConnectorKafkaCluster}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MskconnectConnectorKafkaCluster}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MskconnectConnectorKafkaCluster> {
        com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster apacheKafkaCluster;

        /**
         * Sets the value of {@link MskconnectConnectorKafkaCluster#getApacheKafkaCluster}
         * @param apacheKafkaCluster apache_kafka_cluster block. This parameter is required.
         *                           Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/mskconnect_connector#apache_kafka_cluster MskconnectConnector#apache_kafka_cluster}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder apacheKafkaCluster(com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster apacheKafkaCluster) {
            this.apacheKafkaCluster = apacheKafkaCluster;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MskconnectConnectorKafkaCluster}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MskconnectConnectorKafkaCluster build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MskconnectConnectorKafkaCluster}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MskconnectConnectorKafkaCluster {
        private final com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster apacheKafkaCluster;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.apacheKafkaCluster = software.amazon.jsii.Kernel.get(this, "apacheKafkaCluster", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.apacheKafkaCluster = java.util.Objects.requireNonNull(builder.apacheKafkaCluster, "apacheKafkaCluster is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster getApacheKafkaCluster() {
            return this.apacheKafkaCluster;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("apacheKafkaCluster", om.valueToTree(this.getApacheKafkaCluster()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.mskconnectConnector.MskconnectConnectorKafkaCluster"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MskconnectConnectorKafkaCluster.Jsii$Proxy that = (MskconnectConnectorKafkaCluster.Jsii$Proxy) o;

            return this.apacheKafkaCluster.equals(that.apacheKafkaCluster);
        }

        @Override
        public final int hashCode() {
            int result = this.apacheKafkaCluster.hashCode();
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/mskconnect_connector/MskconnectConnectorKafkaCluster.java <==
package com.hashicorp.cdktf.providers.aws.mskconnect_connector;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.823Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.mskconnectConnector.MskconnectConnectorKafkaCluster")
@software.amazon.jsii.Jsii.Proxy(MskconnectConnectorKafkaCluster.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MskconnectConnectorKafkaCluster extends software.amazon.jsii.JsiiSerializable {

    /**
     * apache_kafka_cluster block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/mskconnect_connector#apache_kafka_cluster MskconnectConnector#apache_kafka_cluster}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster getApacheKafkaCluster();

    /**
     * @return a {@link Builder} of {@link MskconnectConnectorKafkaCluster}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MskconnectConnectorKafkaCluster}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MskconnectConnectorKafkaCluster> {
        com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster apacheKafkaCluster;

        /**
         * Sets the value of {@link MskconnectConnectorKafkaCluster#getApacheKafkaCluster}
         * @param apacheKafkaCluster apache_kafka_cluster block. This parameter is required.
         *                           Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/mskconnect_connector#apache_kafka_cluster MskconnectConnector#apache_kafka_cluster}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder apacheKafkaCluster(com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster apacheKafkaCluster) {
            this.apacheKafkaCluster = apacheKafkaCluster;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MskconnectConnectorKafkaCluster}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MskconnectConnectorKafkaCluster build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MskconnectConnectorKafkaCluster}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MskconnectConnectorKafkaCluster {
        private final com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster apacheKafkaCluster;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.apacheKafkaCluster = software.amazon.jsii.Kernel.get(this, "apacheKafkaCluster", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.apacheKafkaCluster = java.util.Objects.requireNonNull(builder.apacheKafkaCluster, "apacheKafkaCluster is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.mskconnect_connector.MskconnectConnectorKafkaClusterApacheKafkaCluster getApacheKafkaCluster() {
            return this.apacheKafkaCluster;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("apacheKafkaCluster", om.valueToTree(this.getApacheKafkaCluster()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.mskconnectConnector.MskconnectConnectorKafkaCluster"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MskconnectConnectorKafkaCluster.Jsii$Proxy that = (MskconnectConnectorKafkaCluster.Jsii$Proxy) o;

            return this.apacheKafkaCluster.equals(that.apacheKafkaCluster);
        }

        @Override
        public final int hashCode() {
            int result = this.apacheKafkaCluster.hashCode();
            return result;
        }
    }
}
